@@ -3,8 +3,8 @@
   function(data, method, tuneValue, obsLevels, ...)
 {
 
-# pam and will crash if there is a resample with <2 observations
-# in a class. We will detect this and remove those classes.
+                                        # pam and will crash if there is a resample with <2 observations
+                                        # in a class. We will detect this and remove those classes.
   if(method %in% c("pam"))
     {
       yDist <- table(data$.outcome)
@@ -17,26 +17,26 @@
 
   type <- if(is.factor(data$.outcome)) "Classification" else "Regression"
 
-  # whenever possible, instead of using formulas, we will use matrix interfaces to 
-  # call models. For data sets with a lot of factors, the terms 
-  # object created using formulas gets huge and the same thing can 
+                                        # whenever possible, instead of using formulas, we will use matrix interfaces to 
+                                        # call models. For data sets with a lot of factors, the terms 
+                                        # object created using formulas gets huge and the same thing can 
                                         # usually be accomplished with the non-formula interface
 
   modFormula <- as.formula(".outcome ~ .")
 
-  # We refactor the class labels. Some methods bark/crash when there are
-  # factor levels that do not have values represented in the data (nnet produces
-  # a warning and randomForest throws an error). 
+                                        # We refactor the class labels. Some methods bark/crash when there are
+                                        # factor levels that do not have values represented in the data (nnet produces
+                                        # a warning and randomForest throws an error). 
   if(type == "Classification") data$.outcome <- factor(data$.outcome)
 
-  # Later, when we assign predictions, we will convert perdicitons to 
-  # character and then create factors from them with levels originally
-  # found in the object obsLevels.
+                                        # Later, when we assign predictions, we will convert perdicitons to 
+                                        # character and then create factors from them with levels originally
+                                        # found in the object obsLevels.
 
-  # Some routines dont have formula inputs (or dont handle them well)
-  # so extract the feature matrix and class factor.
-  # for svm, we can use the formula interface, but we can't save predicted
-  # probabilites, so we will use the svm(x, y) interface
+                                        # Some routines dont have formula inputs (or dont handle them well)
+                                        # so extract the feature matrix and class factor.
+                                        # for svm, we can use the formula interface, but we can't save predicted
+                                        # probabilites, so we will use the svm(x, y) interface
   if(method %in% c("glmboost", "blackboost", "gamboost", "earth", "earthTest",
                    "bagFDA", "bagEarth", "lda", "enet", "lasso",
                    "lvq", "pls", "plsTest", "gbm", "pam", "rf", "logitBoost",
@@ -46,8 +46,9 @@
                    "lssvmPoly", "lssvmRadial",
                    "rvmRadial", "rvmPoly",
                    "gaussprRadial", "gaussprPoly",
-                   "sddaLDA", "sddaQDA", "glmnet", "slda",
-                   "superpc", "ppr", "sda", "penalized"))
+                   "sddaLDA", "sddaQDA", "glmnet", "slda", "spls", "splsda",
+                   "qda",
+                   "superpc", "ppr", "sda", "penalized", "sparseLDA"))
     {
       trainX <- data[,!(names(data) %in% ".outcome")]
       trainY <- data[,".outcome"] 
@@ -95,15 +96,15 @@
                      },
                      rfNWS =
                      {
-                       # The following is sneaky. I'm trying to avoid having this package
-                       # listed in the description file since it is commercial package and
-                       # not on cran.
+                                        # The following is sneaky. I'm trying to avoid having this package
+                                        # listed in the description file since it is commercial package and
+                                        # not on cran.
                        do.call("library", list("randomForestNWS"))
                        randomForestNWS(trainX, trainY, mtry = tuneValue$.mtry, ...)
                      },
                      rfLSF =
                      {
-                       # See above
+                                        # See above
                        do.call("library", list("caretLSF"))
                        rfLSF(trainX, trainY, mtry = tuneValue$.mtry, ...)
                      },                     
@@ -158,9 +159,9 @@
                      rvmPoly = 
                      {
                        library(kernlab)
-                       # As of version 0.9-5 of kernlab, there was a small inconsistency
-                       # between methods on how to specific kernels. Unlike ksvm, we specify
-                       # them here via kpar (same for polynomial kernels)
+                                        # As of version 0.9-5 of kernlab, there was a small inconsistency
+                                        # between methods on how to specific kernels. Unlike ksvm, we specify
+                                        # them here via kpar (same for polynomial kernels)
 
                        out <- rvm(
                                   as.matrix(trainX),
@@ -346,7 +347,7 @@
                        
                        theDots <- list(...)
                        theDots$keepxy <- TRUE 
-#                       theDots$pmethod <- "none"        
+                                        #                       theDots$pmethod <- "none"        
                        
                        modelArgs <- c(
                                       list(
@@ -434,7 +435,7 @@
                                            control = ctl),
                                       theDots)
                        
-                       # need to do do.call
+                                        # need to do do.call
                        out <- do.call("glmboost", modelArgs)
                        
                        if(tuneValue$.prune == "yes")
@@ -442,9 +443,9 @@
                            out <- if(is.factor(trainY)) out[mstop(AIC(out, "classical"))] else out[mstop(AIC(out))]
                          }
                        
-                       # for easier printing (and tracebacks), we'll try to make the calls shorter
-                       # by adding dummy object names instead of the long obkect definitions that
-                       # currently exist
+                                        # for easier printing (and tracebacks), we'll try to make the calls shorter
+                                        # by adding dummy object names instead of the long obkect definitions that
+                                        # currently exist
                        
                        out$call["x"] <- "xData"         
                        out$call["y"] <- "yData"         
@@ -456,7 +457,7 @@
                      {
                        library(mboost)
                        
-                       #check for control list and over-write mstop
+                                        #check for control list and over-write mstop
                        theDots <- list(...)
                        if(any(names(theDots) == "control"))
                          {
@@ -478,7 +479,7 @@
                                            control = ctl),
                                       theDots)
                        
-                        # need to do do.call
+                                        # need to do do.call
                        out <- do.call("gamboost", modelArgs)
                        
                        if(tuneValue$.prune == "yes")
@@ -486,9 +487,9 @@
                            tmp <- if(is.factor(trainY)) try(out[mstop(AIC(out, "classical"))], silent = TRUE) else try(out[mstop(AIC(out))], silent = TRUE)
                          }
 
-                       # for easier printing (and tracebacks), we'll try to make the calls shorter
-                       # by adding dummy object names instead of the long obkect definitions that
-                        # currently exist
+                                        # for easier printing (and tracebacks), we'll try to make the calls shorter
+                                        # by adding dummy object names instead of the long obkect definitions that
+                                        # currently exist
                        
                        out$call["x"] <- "xData"         
                        out$call["y"] <- "yData"  
@@ -500,7 +501,7 @@
                      {
                        library(mboost)
                        
-                       #check for control lists and over-write mstop and maxdepth
+                                        #check for control lists and over-write mstop and maxdepth
                        
                        theDots <- list(...)
                        
@@ -533,12 +534,12 @@
                                            tree_controls = treeCtl),
                                       theDots)
                        
-                      
+                       
                        out <- do.call("blackboost", modelArgs)
 
-                       # for easier printing (and tracebacks), we'll try to make the calls shorter
-                       # by adding dummy object names instead of the long obkect definitions that
-                       # currently exist
+                                        # for easier printing (and tracebacks), we'll try to make the calls shorter
+                                        # by adding dummy object names instead of the long obkect definitions that
+                                        # currently exist
                        
                        out$call["x"] <- "xData"         
                        out$call["y"] <- "yData"  
@@ -572,9 +573,9 @@
                        
                        out <- do.call("ada", modelArgs)
                        
-                       # for easier printing (and tracebacks), we'll try to make the calls shorter
-                       # by adding dummy object names instead of the long object definitions that
-                       # currently exist
+                                        # for easier printing (and tracebacks), we'll try to make the calls shorter
+                                        # by adding dummy object names instead of the long object definitions that
+                                        # currently exist
                        
                        out$call["x"] <- "xData"         
                        out$call["y"] <- "yData"  
@@ -665,19 +666,19 @@
                        lmbda <- if(method == "lasso") 1 else tuneValue$.lambda
                        enet(as.matrix(trainX), trainY, lambda = lmbda) 
                      },
-#                     glmnet =
-#                     {
-#                       library(glmnet)
-#                       numLev <- if(is.character(trainY) | is.factor(trainY)) length(levels(trainY)) else NA
-#                       if(!is.na(numLev))
-#                         {
-#                           fam <- ifelse(numLev > 2, "multinomial", "binomial")
-#                         } else fam <- "gaussian"
-#                       glmnet(as.matrix(x), y, alpha = tuneValue$.alpha, family = fam, ...)
-#
-#
-#                     },
-                       
+                                        #                     glmnet =
+                                        #                     {
+                                        #                       library(glmnet)
+                                        #                       numLev <- if(is.character(trainY) | is.factor(trainY)) length(levels(trainY)) else NA
+                                        #                       if(!is.na(numLev))
+                                        #                         {
+                                        #                           fam <- ifelse(numLev > 2, "multinomial", "binomial")
+                                        #                         } else fam <- "gaussian"
+                                        #                       glmnet(as.matrix(x), y, alpha = tuneValue$.alpha, family = fam, ...)
+                                        #
+                                        #
+                                        #                     },
+                     
                      sddaLDA = 
                      {
                        library(SDDA)
@@ -800,7 +801,7 @@
                        out <- superpc.train(list(x = t(trainX), y = trainY),
                                             type = "regression",
                                             ...)
-                       # prediction will need to source data, so save that too
+                                        # prediction will need to source data, so save that too
                        out$data <- list(x = t(trainX), y = trainY)
                        out
                      },
@@ -809,10 +810,16 @@
                        library(stats)
                        ppr(as.matrix(trainX), trainY, nterms = tuneValue$.nterms, ...)
                      },
-                     sda =
+                     sparseLDA =
                      {
                        library(sparseLDA)
-                       sda(trainX, trainY, lambda = tuneValue$.lambda, stop = -tuneValue$.NumVars, ...)
+                       sparseLDA:::sda(trainX, trainY, lambda = tuneValue$.lambda, stop = -tuneValue$.NumVars, ...)
+                     },
+                     sda =
+                     {
+                       library(sda)
+                       if(!is.matrix(trainX)) trainX <- as.matrix(trainX)
+                       sda::sda(trainX, trainY, diagonal = tuneValue$.diagonal, ...)
                      },
                      penalized =
                      {
@@ -823,7 +830,55 @@
                                  lambda1 = tuneValue$.lambda1,
                                  lambda2 = tuneValue$.lambda2,
                                  ...)
-                     }
+                     },
+                     spls =
+                     {
+                       library(spls)
+                       spls(trainX, trainY, K = tuneValue$.K, eta = tuneValue$.eta, ...)
+                     },
+                     splsda =
+                     {
+                       library(spls)
+                       splsda(trainX, trainY, K = tuneValue$.K, eta = tuneValue$.eta,
+                              kappa = tuneValue$.kappa, ...)
+                     },
+                     glm = 
+                     {
+                       ##check for family in dot and over-write if none
+                       theDots <- list(...)
+                       if(!any(names(theDots) == "family"))
+                         {
+                           theDots$family <- if(is.factor(data$.outcome)) binomial() else gaussian()              
+                         }
+                       
+                       modelArgs <- c(
+                                      list(formula = modFormula,
+                                           data = data),
+                                      theDots)
+                       
+                       out <- do.call("glm", modelArgs)
+                       out
+                     },
+                     mda =
+                     {
+                       library(mda)
+                       mda(modFormula, data = data, subclasses = tuneValue$.subclasses, ...)
+                     },
+                     pda =
+                     {
+                       library(mda)
+                       fda(modFormula, data = data, method = gen.ridge, lambda = tuneValue$.lambda, ...)
+                     },
+                     pda2 =
+                     {
+                       library(mda)
+                       fda(modFormula, data = data, method = gen.ridge, df = tuneValue$.df, ...)
+                     },                     
+                     qda =
+                     {
+                       library(MASS)
+                       qda(trainX, trainY, ...)
+                     }              
                      )
   
 
@@ -831,11 +886,11 @@
   ## need to cache the model (per Kurt Hornik on 2008-10-05)
   if(method %in% c("JRip", "LMT", "M5Rules", "J48")) .jcache(modelFit$classifier)
   
-  #save a few items so we have a self contained set of information in the model. this will
-  # also carry over to the finalModel if returnData = TRUE in train call
+                                        #save a few items so we have a self contained set of information in the model. this will
+                                        # also carry over to the finalModel if returnData = TRUE in train call
 
-  # for models using S4 classes, you can't easily append data, so 
-  # exclude these and we'll use other methods to get this information
+                                        # for models using S4 classes, you can't easily append data, so 
+                                        # exclude these and we'll use other methods to get this information
   if(!(tolower(method) %in% tolower(c("svmRadial", "svmPoly",
                                       "rvmRadial", "rvmPoly",
                                       "lssvmRadial", "lssvmPoly",
