@@ -35,13 +35,13 @@ probFunction <- function(method, modelFit, newdata)
   if(any(colnames(newdata) == ".outcome")) newdata$.outcome <- NULL
   
   classProb <- switch(method,
-                      lda =, rda =, slda =
+                      lda =, rda =, slda =, qda =
                       {
                         switch(method,
-                               lda =  library(MASS),
-                               rda =  library(klaR),
-                               slda = library(ipred),
-                               sda  = library(sparseLDA))
+                               lda =, qda =  library(MASS),
+                               rda        =  library(klaR),
+                               slda       = library(ipred),
+                               sparseLDA  = library(sparseLDA))
                         
                         out <- predict(modelFit, newdata)$posterior
                         out
@@ -161,9 +161,9 @@ probFunction <- function(method, modelFit, newdata)
                       },
                       gamboost =, blackboost =, glmboost =
                       {
-                        # glmboost defies conveintion a bit by having higher values of the lp
-                        # correspond to the second factor level (as opposed to the first),
-                        # so we use the -lp for the first factor level prob
+                                        # glmboost defies conveintion a bit by having higher values of the lp
+                                        # correspond to the second factor level (as opposed to the first),
+                                        # so we use the -lp for the first factor level prob
                         library(mboost)
                         lp <- predict(modelFit, as.matrix(newdata), type = "lp")
                         out <- cbind(
@@ -188,7 +188,7 @@ probFunction <- function(method, modelFit, newdata)
                       {
                         library(caTools)
                         out <- caTools::predict(modelFit, newdata, type = "raw")
-                        # I've seen them not be on [0, 1]
+                                        # I've seen them not be on [0, 1]
                         out <- t(apply(out, 1, function(x) x/sum(x)))
                         out
                       },
@@ -207,7 +207,33 @@ probFunction <- function(method, modelFit, newdata)
                         out <- cbind(out, 1-out)
                         dimnames(out)[[2]] <-  modelFit$obsLevels
                         out
-                      }
+                      },
+                      splsda =
+                      {
+                        library(spls)
+                        if(!is.matrix(newdata)) newdata <- as.matrix(newdata)
+                        predict(modelFit, newdata, type = "prob")
+                      },
+                      sda =
+                      {                  
+                        library(sda)
+                        if(!is.matrix(newdata)) newdata <- as.matrix(newdata)
+                        sda::predict.sda(modelFit, newdata)$prob
+                      },
+                      glm =
+                      {
+                        
+                        out <- predict(modelFit, newdata, type = "response")
+                        out <- cbind(1-out, out)
+                        ## glm models the second factor level. See Details in ?glm
+                        dimnames(out)[[2]] <-  modelFit$obsLevels
+                        out
+                      },
+                      mda =, pda =, pda2 =
+                      {
+                        library(mda)
+                        predict(modelFit, newdata, type = "posterior")
+                      }                     
                       )
 
   if(!is.data.frame(classProb)) classProb <- as.data.frame(classProb)
