@@ -19,7 +19,7 @@ byComplexity <- function(x, model)
              x[order(x$n.trees, x$interaction.depth, x$shrinkage),] 
            },
            rf =, rfNWS =, rfLSF =, gpls =, pls =, PLS =, pam =, cforest =,
-           nb =, rpart =, ctree2 =, logitBoost=, J48 =, LMT =, ppr = 
+           nb =, rpart =, ctree2 =, logitBoost=, J48 =, LMT =, ppr =, mda =, pda =, pda2 =   
            {
              x[order(x[,1]),]
            },
@@ -60,7 +60,7 @@ byComplexity <- function(x, model)
              x[order(x$degree, x$nprune),]
            },
            treebag =, lda =, lm =, sddaLDA =, sddaQDA =,
-           lmStepAIC =, slda =
+           lmStepAIC =, slda =, glm =, qda =
            {
              x
            },
@@ -95,14 +95,19 @@ byComplexity <- function(x, model)
            {
              x[order(x$threshold, x$n.components),]
            },
-           sda =
+           sparseLDA =
            {
              x[order(x$NumVars, x$lambda),]
            },
            penalized =
            {
              x[order(x$lambda1, x$lambda2),]
-           }
+           },
+           spls =, splsda = 
+           {
+             x[order(-x$eta, x$K),]
+           },
+           sda = x[order(x$diagonal),]
            )
 
   }
